"""
:authors: Tarodictrl
:license: MIT License, see LICENSE file
:copyright: (c) 2022 Tarodictrl
"""

from .__main__ import *


__author__ = "Tarodictrl"
__version__ = "0.0.1"
__license__ = "MIT License"
__email__ = "vudi600@gmail.com"
